summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmtreeviewitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmtreeviewitem.h')
-rw-r--r--kpovmodeler/pmtreeviewitem.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kpovmodeler/pmtreeviewitem.h b/kpovmodeler/pmtreeviewitem.h
index 81fdeb96..7792871a 100644
--- a/kpovmodeler/pmtreeviewitem.h
+++ b/kpovmodeler/pmtreeviewitem.h
@@ -36,24 +36,24 @@ class PMTreeViewItem : public TQListViewItem
{
public:
/**
* Constructs a new top-level list view item in the TQListView tqparent.
*/
- PMTreeViewItem( PMObject* object, TQListView* tqparent );
+ PMTreeViewItem( PMObject* object, TQListView* parent );
/**
* Constructs a new list view item which is a child of tqparent and
* first in the tqparent's list of tqchildren.
*/
- PMTreeViewItem( PMObject* object, TQListViewItem* tqparent );
+ PMTreeViewItem( PMObject* object, TQListViewItem* parent );
/**
* Constructs a list view item which is a child of tqparent
* and is after after in the tqparent's list of tqchildren.
*/
- PMTreeViewItem( PMObject* object, TQListView* tqparent, TQListViewItem* after );
+ PMTreeViewItem( PMObject* object, TQListView* parent, TQListViewItem* after );
/**
* Constructs a list view item which is a child of tqparent
* and is after after in the tqparent's list of tqchildren.
*/
- PMTreeViewItem( PMObject* object, TQListViewItem* tqparent,
+ PMTreeViewItem( PMObject* object, TQListViewItem* parent,
TQListViewItem* after );
/**
* Returns the connected @ref PMObject
@@ -65,11 +65,11 @@ public:
*/
virtual TQString key( int column, bool ascending ) const;
/**
* Returns a pointer to the tqparent item
*/
- PMTreeViewItem* tqparent( )
+ PMTreeViewItem* parent( )
{
- return ( PMTreeViewItem* ) TQListViewItem::tqparent( );
+ return ( PMTreeViewItem* ) TQListViewItem::parent( );
}
void setSelected( bool select );
@@ -36,24 +36,24 @@ class PMTreeViewItem : public TQListViewItem
public:
/**
- * Constructs a new top-level list view item in the TQListView tqparent.
+ * Constructs a new top-level list view item in the TQListView parent.
*/
@@ -36,24 +36,24 @@ class PMTreeViewItem : public TQListViewItem
/**
- * Constructs a new list view item which is a child of tqparent and
- * first in the tqparent's list of tqchildren.
+ * Constructs a new list view item which is a child of parent and
+ * first in the parent's list of tqchildren.
*/
@@ -36,24 +36,24 @@ class PMTreeViewItem : public TQListViewItem
/**
- * Constructs a list view item which is a child of tqparent
- * and is after after in the tqparent's list of tqchildren.
+ * Constructs a list view item which is a child of parent
+ * and is after after in the parent's list of tqchildren.
*/
@@ -36,24 +36,24 @@ class PMTreeViewItem : public TQListViewItem
/**
- * Constructs a list view item which is a child of tqparent
- * and is after after in the tqparent's list of tqchildren.
+ * Constructs a list view item which is a child of parent
+ * and is after after in the parent's list of tqchildren.
*/
@@ -65,11 +65,11 @@ public:
virtual TQString key( int column, bool ascending ) const;
/**
- * Returns a pointer to the tqparent item
+ * Returns a pointer to the parent item
*/